@@ -19,11 +19,11 @@ FCGI::Buffer - Verify, Cache and Optimise FCGI Output
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
@@ -605,7 +605,12 @@ sub DESTROY {
 							$script_name = $ENV{'SCRIPT_NAME'};
 							$copy =~ s/<a\s+href="(\?.+?)"/<a href="$script_name$1"/gi;
 
-							print $fout $copy;
+							# Avoide Wide character
+							unless($self->{_encode_loaded}) {
+								require Encode;
+								$self->{_encode_loaded} = 1;
+							}
+							print $fout Encode::encode_utf8($copy);
 							close $fout;
 							# Do INSERT OR REPLACE in case another program has
 							# got in first,
@@ -965,6 +970,12 @@ To enable save_to, a info and lingua arguments must also be given.
 It works best when cache is also given.
 Only use where output is guaranteed to be the same with a given set of arguments
 (the same criteria for enabling generate_304).
+You can turn it off on a case by case basis thus:
+
+    my $params = CGI::Info->new()->params();
+    if($params->{'send_private_email'}) {
+        $buffer->init('save_to' => undef);
+    }
 
 Info is an optional argument to give information about the FCGI environment, e.g.
 a L<CGI::Info> object.
@@ -1023,6 +1034,8 @@ sub init {
 		if(!exists($params{save_to})) {
 			$self->{save_to} = 600;
 		}
+	} elsif(exists($params{'save_to'}) && !defined($params{'save_to'})) {
+		delete $self->{'save_to'};
 	}
 	if(defined($params{generate_304})) {
 		$self->{generate_304} = $params{generate_304};
